最后刷新一下源列表

sudo apt-get update

  • 没有对应的模块。解决方法:缺什么模块就安装什么模块

我出现的就是这个问题,所以详细写一下

在输入python3 oneforall.py --help后,出现下图错误

缺少fire模块

提示缺少fire模块,安装一下就行

pip3 install fire

我以为安装一个模块就行了,但是,这只是一个开始,安装好后我又输入python3 oneforall.py --help 发现又出现缺少模块,我直接把缺少的模块截图全部附一下

在这里插入图片描述
在这里插入图片描述
在这里插入图片描述
在这里插入图片描述

出一个,我直接 pip3 install xx 一个,最后终于跳出帮助页面

退出帮助页面 :q

然后我查看了一下这个oneforall的版本

python3 onforall.py version

4. 帮助文档

最后附上OneForAll v0.4.5 的文档

NAME
    oneforall.py - OneForAll help summary page

SYNOPSIS
    oneforall.py COMMAND | <flags>

DESCRIPTION
    OneForAll is a powerful subdomain integration tool

    Example:
        python3 oneforall.py version
        python3 oneforall.py check
        python3 oneforall.py --target example.com run
        python3 oneforall.py --targets ./domains.txt run
        python3 oneforall.py --target example.com --alive False run
        python3 oneforall.py --target example.com --brute False run
        python3 oneforall.py --target example.com --port medium run
        python3 oneforall.py --target example.com --fmt csv run
        python3 oneforall.py --target example.com --dns False run
        python3 oneforall.py --target example.com --req False run
        python3 oneforall.py --target example.com --takeover False run
        python3 oneforall.py --target example.com --show True run

    Note:
        --port   small/medium/large  See details in ./config/setting.py(default small)
        --fmt    csv/json (result format)
        --path   Result path (default None, automatically generated)
FLAGS
    --target=TARGET
        Type: Optional[]
        Default: None
        One domain (target or targets must be provided)
    --targets=TARGETS
        Type: Optional[]
        Default: None
        File path of one domain per line
    -b, --brute=BRUTE
        Type: Optional[]
        Default: None
        Use brute module (default True)
    -d, --dns=DNS
        Type: Optional[]
        Default: None
        Use DNS resolution (default True)
    -r, --req=REQ
        Type: Optional[]
        Default: None
        HTTP request subdomains (default True)
    --port=PORT
        Type: Optional[]
        Default: None
        The port range to request (default small port is 80,443)
    -a, --alive=ALIVE
        Type: Optional[]
        Default: None
        Only export alive subdomains (default False)
    -f, --fmt=FMT
        Type: Optional[]
        Default: None
        Result format (default csv)
    --path=PATH
        Type: Optional[]
        Default: None
        Result path (default None, automatically generated)
    --takeover=TAKEOVER
        Type: Optional[]
        Default: None
        Scan subdomain takeover (default False)

COMMANDS


**自我介绍一下,小编13年上海交大毕业,曾经在小公司待过,也去过华为、OPPO等大厂,18年进入阿里一直到现在。**

**深知大多数网络安全工程师,想要提升技能,往往是自己摸索成长,但自己不成体系的自学效果低效又漫长,而且极易碰到天花板技术停滞不前!**

**因此收集整理了一份《2024年网络安全全套学习资料》,初衷也很简单,就是希望能够帮助到想自学提升又不知道该从何学起的朋友。**
![img](https://img-blog.csdnimg.cn/img_convert/2f6f8249c257ef61c1cfe7ddac1d2066.png)
![img](https://img-blog.csdnimg.cn/img_convert/ee289ab7adcd7bc44cd4db93a78f3a3a.png)
![img](https://img-blog.csdnimg.cn/img_convert/7b84cd982ef2f685c68296ae47716726.png)
![img](https://img-blog.csdnimg.cn/img_convert/67146647b52c48d999db50ded09533b6.png)
![img](https://img-blog.csdnimg.cn/img_convert/84e69f882c194cac8b8e9a0a23a69f70.png)
![img](https://img-blog.csdnimg.cn/img_convert/f989d152ce8a23a685c049d7e16700d8.png)

**既有适合小白学习的零基础资料,也有适合3年以上经验的小伙伴深入学习提升的进阶课程,基本涵盖了95%以上网络安全知识点,真正体系化!**

**由于文件比较大,这里只是将部分目录大纲截图出来,每个节点里面都包含大厂面经、学习笔记、源码讲义、实战项目、讲解视频,并且后续会持续更新**

**如果你觉得这些内容对你有帮助,可以添加VX:vip204888 (备注网络安全获取)**
![img](https://img-blog.csdnimg.cn/img_convert/b54ca877f6bbe60c4395d7a9780b934b.png)

纲截图出来,每个节点里面都包含大厂面经、学习笔记、源码讲义、实战项目、讲解视频,并且后续会持续更新**

**如果你觉得这些内容对你有帮助,可以添加VX:vip204888 (备注网络安全获取)**
[外链图片转存中...(img-crvzxM0E-1712973865201)]

更多推荐